@@ -1,7 +1,9 @@
-# $Id: soap.pm 11480 2007-06-14 14:16:21Z sendu $
+# $Id: soap.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module Bio::DB::Biblio::soap.pm
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Martin Senger <senger@ebi.ac.uk>
 # For copyright and disclaimer see below.
 
@@ -37,6 +39,17 @@ the Bioperl mailing list.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
@@ -117,6 +130,8 @@ BEGIN {
     $DEFAULT_SERVICE = 'http://www.ebi.ac.uk/openbqs/services/MedlineSRS';
 
     # ...and what to find there
+    
+    ## TODO: This namespace is no longer valid (check for deprecation or update)
     $DEFAULT_NAMESPACE = 'http://industry.ebi.ac.uk/openBQS';
 }
 
@@ -135,6 +150,9 @@ BEGIN {
                uniqueness - therefore it often has a style of a URL -
                but it does not mean that such pseudo-URL really exists.
 
+               ## TODO: This namespace is no longer valid (check for deprecation
+               ## or update)
+               
                Default is 'http://industry.ebi.ac.uk/openBQS'.
 
              -destroy_on_exit => '0'
